particleShear
Python package for particle shear simulation

This package provides a discrete particle simulation kit for having multiple spheres interacting. The spheres (i.e. 2D circles) interact by mutual elastic repulsion and tangential friction upon contact, but can also be crosslinked together. In addition to the elementary implementation of the interacting particles, it is also possible to define rheological experiments where the spheres are exposed to sinusoidally varying displacement conditions on the boundaries.

Acknowledgement: Thanks from the author (Thomas Braschler) go to Fabien Bonini and Joé Brefie-Guth for package testing, and to Daniel Lyobenov for initial help with simulation setup.
